<?php

/**
 * @file
 * Defines the "language" plugin.
 */

/**
 * Config for the "language" CKEditor plugin.
 *
 * @param object $format
 *  A text format object.
 *
 * @return array
 *   An associative array of configuration settings.
 */
function editor_ckeditor_language_config($format) {
  // Add the language list if configured.
  $language_list = array();
  $config = array('language_list' => 'un');
  $settings = $format->editor_settings;

  if (isset($settings['plugins']['language'])) {
    $config = $settings['plugins']['language'];
  }

  $predefined_languages = ($config['language_list'] === 'all') ?
    editor_standard_language_list() :
    editor_united_nations_language_list();

  // Generate the language_list setting as expected by the CKEditor Language
  // plugin, but key the values by the full language name so that we can sort
  // them later on.
  foreach ($predefined_languages as $langcode => $lang) {
    $english_name = $lang[0];
    $direction = empty($lang[2]) ? NULL : $lang[2];

    if ($direction === 'rtl') {
      $language_list[$english_name] = $langcode . ':' . $english_name . ':rtl';
    }
    else {
      $language_list[$english_name] = $langcode . ':' . $english_name;
    }
  }

  // Sort on full language name.
  ksort($language_list);
  $config['language_list'] = array_values($language_list);

  return $config;
}

/**
 * Subform constructor to configure the text editor's image upload settings.
 *
 * Each text editor plugin that is configured to offer the ability to insert
 * images and uses EditorImageDialog for that, should use this form to update
 * the text editor's configuration so that EditorImageDialog knows whether it
 * should allow the user to upload images.
 *
 * @param object $format
 *   The text format that is being edited.
 *
 * @return array
 *   The image upload settings form.
 *
 * @ingroup forms
 */
function editor_ckeditor_language_settings_form($form, &$form_state, $format) {
  // Defaults.
  $config = array('language_list' => 'un');
  $settings = $format->editor_settings;
  if (isset($settings['plugins']['language'])) {
    $config = $settings['plugins']['language'];
  }

  $predefined_languages = editor_standard_language_list();
  $form['language_list'] = array(
    '#title' => t('Language list'),
    '#title_display' => 'invisible',
    '#type' => 'select',
    '#options' => array(
      'un' => t("United Nations' official languages"),
      'all' => t('All @count languages', array('@count' => count($predefined_languages))),
    ),
    '#default_value' => $config['language_list'],
    '#description' => t('The list of languages to show in the language dropdown. The basic list will only show the <a href="@url">six official languages of the UN</a>. The extended list will show all @count languages that are available in Drupal.', array(
      '@url' => 'http://www.un.org/en/aboutun/languages.shtml/',
      '@count' => count($predefined_languages),
    )),
    '#attached' => array('library' => array(array('editor_ckeditor', 'editor_ckeditor.language.admin'))),
  );

  return $form;
}
